@@ -436,76 +436,3 @@
 }
 
 
-
-# Function to fit a circle through three points
-.fit_circle <- function(points) {
-  x <- points[, 1]
-  y <- points[, 2]
-
-  D <- 2 * (x[1] * (y[2] - y[3]) + x[2] * (y[3] - y[1]) + x[3] * (y[1] - y[2]))
-
-  Ux <- ((x[1]^2 + y[1]^2) * (y[2] - y[3]) + (x[2]^2 + y[2]^2) * (y[3] - y[1]) + (x[3]^2 + y[3]^2) * (y[1] - y[2])) / D
-  Uy <- ((x[1]^2 + y[1]^2) * (x[3] - x[2]) + (x[2]^2 + y[2]^2) * (x[1] - x[3]) + (x[3]^2 + y[3]^2) * (x[2] - x[1])) / D
-
-  center <- c(Ux, Uy)
-  radius <- sqrt((x[1] - Ux)^2 + (y[1] - Uy)^2)
-
-  return(list(center = center, radius = radius))
-}
-
-.RANSAC <- function(data){
-
-  dat <- data
-
-  dist <- 0.05
-
-  inliers <- dat[sample(nrow(dat), 3), ]
-
-  fit <- .fit_circle(inliers)
-
-  radio <- sqrt((dat[, "x"] - fit$center[1]) ^ 2 + (dat[, "y"] - fit$center[2]) ^ 2)
-  dat <- cbind(dat, radio)
-  inliers <- abs(fit$radius-dat[, "radio"])
-  dat <- cbind(dat, inliers)
-  dat <- dat[dat[, "inliers"] < dist, ]
-
-  if(length(dat) == 0 | nrow(dat) < 2){
-
-    out <- data.frame(x = as.numeric(), y = as.numeric(),
-                      radio = as.numeric(), n = as.numeric(), mae = as.numeric(), cv = as.numeric())
-
-    return(out)}
-
-
-  dat <- dat[, c("x", "y")]
-
-  inliers <- dat[sample(nrow(dat), 3), ]
-
-  fit <- .fit_circle(inliers)
-
-
-  radio <- sqrt((dat[, "x"] - fit$center[1]) ^ 2 + (dat[, "y"] - fit$center[2]) ^ 2)
-  dat <- cbind(dat, radio)
-  inliers <- abs(fit$radius-dat[, "radio"])
-  dat <- cbind(dat, inliers)
-  dat <- dat[dat[, "inliers"] < dist, ]
-
-  if(length(dat) == 0 | nrow(dat) < 2){
-
-    out <- data.frame(x = as.numeric(), y = as.numeric(),
-                      radio = as.numeric(), n = as.numeric(), mae = as.numeric(), cv = as.numeric())
-
-    return(out)}
-
-  mae <- abs(sum(coef(fit)[1]-dat[, 3])) / nrow(dat)
-  cv <- stats::sd(raster::pointDistance(dat[, c("x", "y")], c(fit$center[1], fit$center[2]), lonlat = FALSE)) / fit$radius
-
-  out <- data.frame(x = fit$center[1], y = fit$center[2], radio = fit$radius, n = nrow(dat), mae = mae, cv = cv)
-
-  return(out)
-
-}
-
-
-
-
